'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _reactIntl = require('react-intl');

var _cspaceLayout = require('cspace-layout');

var _CancelButton = require('../navigation/CancelButton');

var _CancelButton2 = _interopRequireDefault(_CancelButton);

var _SaveButton = require('../record/SaveButton');

var _SaveButton2 = _interopRequireDefault(_SaveButton);

var _RevertButton = require('../record/RevertButton');

var _RevertButton2 = _interopRequireDefault(_RevertButton);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const messages = (0, _reactIntl.defineMessages)({
  title: {
    'id': 'confirmRecordNavigationModal.title',
    'defaultMessage': 'Leave Record?'
  },
  prompt: {
    'id': 'confirmRecordNavigationModal.prompt',
    'defaultMessage': 'You\'re about to leave a record that has unsaved changes.'
  },
  cancel: {
    'id': 'confirmRecordNavigationModal.cancel',
    'defaultMessage': 'Don\'t leave'
  },
  save: {
    'id': 'confirmRecordNavigationModal.save',
    'defaultMessage': 'Save and continue'
  },
  revert: {
    'id': 'confirmRecordNavigationModal.revert',
    'defaultMessage': 'Revert and continue'
  }
});

const propTypes = {
  isOpen: _propTypes2.default.bool,
  isModified: _propTypes2.default.bool,
  isSavePending: _propTypes2.default.bool,
  validationErrors: _propTypes2.default.instanceOf(_immutable2.default.Map),
  onCancelButtonClick: _propTypes2.default.func,
  onCloseButtonClick: _propTypes2.default.func,
  onRevertButtonClick: _propTypes2.default.func,
  onSaveButtonClick: _propTypes2.default.func,
  onSaveButtonErrorBadgeClick: _propTypes2.default.func
};

class ConfirmRecordNavigationModal extends _react.Component {
  constructor() {
    super();

    this.renderButtonBar = this.renderButtonBar.bind(this);
  }

  renderButtonBar() {
    var _props = this.props;
    const isModified = _props.isModified,
          isSavePending = _props.isSavePending,
          validationErrors = _props.validationErrors,
          onCancelButtonClick = _props.onCancelButtonClick,
          onSaveButtonClick = _props.onSaveButtonClick,
          onSaveButtonErrorBadgeClick = _props.onSaveButtonErrorBadgeClick,
          onRevertButtonClick = _props.onRevertButtonClick;


    return _react2.default.createElement(
      'div',
      null,
      _react2.default.createElement(_CancelButton2.default, {
        label: _react2.default.createElement(_reactIntl.FormattedMessage, messages.cancel),
        onClick: onCancelButtonClick
      }),
      _react2.default.createElement(_SaveButton2.default, {
        isModified: isModified,
        isSavePending: isSavePending,
        label: _react2.default.createElement(_reactIntl.FormattedMessage, messages.save),
        validationErrors: validationErrors,
        onClick: onSaveButtonClick,
        onErrorBadgeClick: onSaveButtonErrorBadgeClick
      }),
      _react2.default.createElement(_RevertButton2.default, {
        isModified: isModified,
        isSavePending: isSavePending,
        label: _react2.default.createElement(_reactIntl.FormattedMessage, messages.revert),
        onClick: onRevertButtonClick
      })
    );
  }

  render() {
    var _props2 = this.props;
    const isOpen = _props2.isOpen,
          onCloseButtonClick = _props2.onCloseButtonClick;


    return _react2.default.createElement(
      _cspaceLayout.Modal,
      {
        isOpen: isOpen,
        title: _react2.default.createElement(
          'h1',
          null,
          _react2.default.createElement(_reactIntl.FormattedMessage, messages.title)
        ),
        closeButtonClassName: 'material-icons',
        closeButtonLabel: 'close',
        renderButtonBar: this.renderButtonBar,
        onCloseButtonClick: onCloseButtonClick
      },
      _react2.default.createElement(_reactIntl.FormattedMessage, messages.prompt)
    );
  }
}

exports.default = ConfirmRecordNavigationModal;
ConfirmRecordNavigationModal.modalName = 'ConfirmRecordNavigationModal';
ConfirmRecordNavigationModal.propTypes = propTypes;